# frozen_string_literal: true

Application.boot(:cache, namespace: true) do
  init do
    require "cht-lib-fabric/clients/redis"
    require "containers_cp/common_assets"
    require "containers_cp/shard_lookup"
  end

  start do
    # common assets cache
    register(:common_assets, ::ContainersCp::CommonAssets.new)

    redis_host = target[:settings].redis_host
    redis_port = target[:settings].redis_port

    SSL_ENVS = %w[production staging]
    # rediss:// is not a typo.
    # Enables SSL connection within `redis` gem.
    redis_uri_scheme = SSL_ENVS.include?(ENV['RACK_ENV'])  && ENV["DEPLOYMENT_PROVIDER"].downcase == "aws" ? 'rediss://' : 'redis://'
    redis_url = "#{redis_uri_scheme}#{redis_host}:#{redis_port}"
    puts("redis cache URL: #{redis_url}")

    log = target[:settings].redis_debug.empty? ? nil : target[:logger]

    cache_redis = ::Platform::Clients::Redis.new(
      url: redis_url,
      logger: log,
      namespace: SERVICE_NAME,
      auto_reconnect: true,
      thread_safe: true
    )
    register(:redis, cache_redis)
  end
end
